@@ -8,7 +8,7 @@
 
     .. note: the code in this module is not used by Babel itself
 
-    :copyright: (c) 2013-2018 by the Babel Team.
+    :copyright: (c) 2013-2021 by the Babel Team.
     :license: BSD, see LICENSE for more details.
 """
 
@@ -79,7 +79,7 @@ class Format(object):
         return format_time(time, format, tzinfo=self.tzinfo, locale=self.locale)
 
     def timedelta(self, delta, granularity='second', threshold=.85,
-                  format='medium', add_direction=False):
+                  format='long', add_direction=False):
         """Return a time delta according to the rules of the given locale.
 
         >>> from datetime import timedelta
@@ -165,7 +165,7 @@ class LazyProxy(object):
     Hello, universe!
     Hello, world!
     """
-    __slots__ = ['_func', '_args', '_kwargs', '_value', '_is_cache_enabled']
+    __slots__ = ['_func', '_args', '_kwargs', '_value', '_is_cache_enabled', '_attribute_error']
 
     def __init__(self, func, *args, **kwargs):
         is_cache_enabled = kwargs.pop('enable_cache', True)
@@ -175,11 +175,17 @@ class LazyProxy(object):
         object.__setattr__(self, '_kwargs', kwargs)
         object.__setattr__(self, '_is_cache_enabled', is_cache_enabled)
         object.__setattr__(self, '_value', None)
+        object.__setattr__(self, '_attribute_error', None)
 
     @property
     def value(self):
         if self._value is None:
-            value = self._func(*self._args, **self._kwargs)
+            try:
+                value = self._func(*self._args, **self._kwargs)
+            except AttributeError as error:
+                object.__setattr__(self, '_attribute_error', error)
+                raise
+
             if not self._is_cache_enabled:
                 return value
             object.__setattr__(self, '_value', value)
@@ -249,6 +255,8 @@ class LazyProxy(object):
         delattr(self.value, name)
 
     def __getattr__(self, name):
+        if self._attribute_error is not None:
+            raise self._attribute_error
         return getattr(self.value, name)
 
     def __setattr__(self, name, value):
@@ -343,7 +351,7 @@ class NullTranslations(gettext.NullTranslations, object):
     dungettext = udngettext
 
     # Most of the downwards code, until it get's included in stdlib, from:
-    #    http://bugs.python.org/file10036/gettext-pgettext.patch
+    #    https://bugs.python.org/file10036/gettext-pgettext.patch
     #
     # The encoding of a msgctxt and a msgid in a .mo file is
     # msgctxt + "\x04" + msgid (gettext version >= 0.15)
